@@ -328,14 +328,14 @@ struct DirSource {
     nickname: String,
     /// DOCDOC -- I forget.  Is this the identity fingerprint for the
     /// authority identity key, or for the identity key of the authority
-    /// when it's runnign as a relay?
+    /// when it's running as a relay?
     identity: RsaIdentity,
     /// Address of the authority in string form.
     // XXXX why do we have this _and_ IP?
     address: String,
     /// IP address for the authority
     ip: net::IpAddr,
-    /// HTTP directory port for this authoirty
+    /// HTTP directory port for this authority
     dir_port: u16,
     /// OR port for this authority.
     or_port: u16,
@@ -398,7 +398,6 @@ bitflags! {
 #[derive(Debug, Clone, Copy)]
 #[non_exhaustive]
 pub enum RelayWeight {
-    // TODO SPEC: Document that these are u32 in dir-spec.txt
     /// An unmeasured weight for a relay.
     Unmeasured(u32),
     /// An measured weight for a relay.
@@ -793,7 +792,8 @@ impl CommonHeader {
 
         {
             // this unwrap is safe because if there is not at least one
-            // token in the section, the section is unparseable.
+            // token in the section, the section is unparsable.
+            #[allow(clippy::unwrap_used)]
             let first = sec.first_item().unwrap();
             if first.kwd() != NETWORK_STATUS_VERSION {
                 return Err(Error::UnexpectedToken(first.kwd().to_str(), first.pos()));
@@ -904,12 +904,12 @@ impl ConsensusHeader {
 
         let shared_rand_prev = sec
             .get(SHARED_RAND_PREVIOUS_VALUE)
-            .map(|i| SharedRandVal::from_item(i))
+            .map(SharedRandVal::from_item)
             .transpose()?;
 
         let shared_rand_cur = sec
             .get(SHARED_RAND_CURRENT_VALUE)
-            .map(|i| SharedRandVal::from_item(i))
+            .map(SharedRandVal::from_item)
             .transpose()?;
 
         Ok(ConsensusHeader {
@@ -949,8 +949,12 @@ impl ConsensusVoterInfo {
     /// Parse a single ConsensusVoterInfo from a voter info section.
     fn from_section(sec: &Section<'_, NetstatusKwd>) -> Result<ConsensusVoterInfo> {
         use NetstatusKwd::*;
-        if sec.first_item().unwrap().kwd() != DIR_SOURCE {
-            return Err(Error::Internal(sec.first_item().unwrap().pos()));
+        // this unwrap should be safe because if there is not at least one
+        // token in the section, the section is unparsable.
+        #[allow(clippy::unwrap_used)]
+        let first = sec.first_item().unwrap();
+        if first.kwd() != DIR_SOURCE {
+            return Err(Error::Internal(first.pos()));
         }
         let dir_source = DirSource::from_item(sec.required(DIR_SOURCE)?)?;
 
@@ -1007,9 +1011,18 @@ impl RelayFlags {
                     ));
                 }
             }
-            let fl = s.parse().unwrap();
-            flags |= fl;
-            prev = Some(s);
+            match s.parse() {
+                Ok(fl) => {
+                    flags |= fl;
+                    prev = Some(s);
+                }
+                Err(_e) => {
+                    return Err(Error::BadArgument(
+                        item.pos(),
+                        "failed to parse flag".to_string(),
+                    ))
+                }
+            };
         }
 
         Ok(flags)
@@ -1073,7 +1086,7 @@ enum SigCheckResult {
     /// The signature is invalid; no additional information could make it
     /// valid.
     Invalid,
-    /// We can't check the signatuer because we don't have a
+    /// We can't check the signature because we don't have a
     /// certificate with the right signing key.
     MissingCert,
 }
@@ -1257,8 +1270,11 @@ impl<RS: RouterStatus + ParseRouterStatus> Consensus<RS> {
         let (header, start_pos) = {
             let mut h = r.pause_at(|i| i.is_ok_with_kwd_in(&[DIR_SOURCE]));
             let header_sec = NS_HEADER_RULES_CONSENSUS.parse(&mut h)?;
-            let pos = header_sec.first_item().unwrap().offset_in(r.str());
-            (ConsensusHeader::from_section(&header_sec)?, pos.unwrap())
+            // Unwrapping should be safe because above `.parse` would have
+            // returned an Error
+            #[allow(clippy::unwrap_used)]
+            let pos = header_sec.first_item().unwrap().offset_in(r.str()).unwrap();
+            (ConsensusHeader::from_section(&header_sec)?, pos)
         };
         if RS::flavor() != header.hdr.flavor {
             return Err(Error::BadDocumentType);
@@ -1305,11 +1321,12 @@ impl<RS: RouterStatus + ParseRouterStatus> Consensus<RS> {
             signatures.push(sig);
         }
 
-        if first_sig.is_none() {
-            return Err(Error::MissingToken("directory-signature"));
-        }
-
-        let end_pos = first_sig.unwrap().offset_in(r.str()).unwrap() + "directory-signature ".len();
+        let end_pos = match first_sig {
+            None => return Err(Error::MissingToken("directory-signature")),
+            // Unwrap should be safe because `first_sig` was parsed from `r`
+            #[allow(clippy::unwrap_used)]
+            Some(sig) => sig.offset_in(r.str()).unwrap() + "directory-signature ".len(),
+        };
 
         // Find the appropriate digest.
         let signed_str = &r.str()[start_pos..end_pos];
@@ -1414,13 +1431,15 @@ impl<RS> ExternallySigned<Consensus<RS>> for UnvalidatedConsensus<RS> {
         }
     }
     fn is_well_signed(&self, k: &Self::Key) -> result::Result<(), Self::Error> {
-        if self.n_authorities.is_none() {
-            return Err(Error::Internal(Pos::None));
-        }
-        if self.siggroup.validate(self.n_authorities.unwrap(), k) {
-            Ok(())
-        } else {
-            Err(Error::BadSignature(Pos::None))
+        match self.n_authorities {
+            None => Err(Error::Internal(Pos::None)),
+            Some(authority) => {
+                if self.siggroup.validate(authority, k) {
+                    Ok(())
+                } else {
+                    Err(Error::BadSignature(Pos::None))
+                }
+            }
         }
     }
     fn dangerously_assume_wellsigned(self) -> Consensus<RS> {
@@ -1503,6 +1522,8 @@ impl SignatureGroup {
                 continue;
             }
 
+            // Unwrap should be safe because of above `d.is_none()` check
+            #[allow(clippy::unwrap_used)]
             match sig.check_signature(d.as_ref().unwrap(), certs) {
                 SigCheckResult::Valid => {
                     ok.insert(*id_fingerprint);
@@ -1517,6 +1538,7 @@ impl SignatureGroup {
 
 #[cfg(test)]
 mod test {
+    #![allow(clippy::unwrap_used)]
     use super::*;
     use hex_literal::hex;
 
@@ -1571,10 +1593,7 @@ mod test {
         assert_eq!(2, missing.len());
 
         // here is a trick that had better not work.
-        let mut same_three_times = Vec::new();
-        same_three_times.push(certs[0].clone());
-        same_three_times.push(certs[0].clone());
-        same_three_times.push(certs[0].clone());
+        let same_three_times = vec![certs[0].clone(), certs[0].clone(), certs[0].clone()];
         let missing = consensus.key_is_correct(&same_three_times).err().unwrap();
 
         assert_eq!(2, missing.len());
@@ -1593,8 +1612,8 @@ mod test {
             r0.rsa_identity().as_bytes(),
             &hex!("0a3057af2910415794d8ea430309d9ac5f5d524b")
         );
-        assert_eq!(r0.weight().is_measured(), false);
-        assert_eq!(r0.weight().is_nonzero(), false);
+        assert!(!r0.weight().is_measured());
+        assert!(!r0.weight().is_nonzero());
         let pv = &r0.protovers();
         assert!(pv.supports_subver("HSDir", 2));
         assert!(!pv.supports_subver("HSDir", 3));
@@ -1634,41 +1653,41 @@ mod test {
     #[test]
     fn test_bad() {
         use crate::Pos;
-        fn check(fname: &str, e: Error) {
+        fn check(fname: &str, e: &Error) {
             let content = read_bad(fname);
             let res = MdConsensus::parse(&content);
             assert!(res.is_err());
-            assert_eq!(res.err().unwrap(), e);
+            assert_eq!(&res.err().unwrap(), e);
         }
 
         check(
             "bad-flags",
-            Error::BadArgument(Pos::from_line(27, 1), "Flags out of order".into()),
+            &Error::BadArgument(Pos::from_line(27, 1), "Flags out of order".into()),
         );
         check(
             "bad-md-digest",
-            Error::BadArgument(Pos::from_line(40, 3), "Invalid base64".into()),
+            &Error::BadArgument(Pos::from_line(40, 3), "Invalid base64".into()),
         );
         check(
             "bad-weight",
-            Error::BadArgument(
+            &Error::BadArgument(
                 Pos::from_line(67, 141),
                 "invalid digit found in string".into(),
             ),
         );
         check(
             "bad-weights",
-            Error::BadArgument(
+            &Error::BadArgument(
                 Pos::from_line(51, 13),
                 "invalid digit found in string".into(),
             ),
         );
-        check("wrong-order", Error::WrongSortOrder(Pos::from_line(52, 1)));
+        check("wrong-order", &Error::WrongSortOrder(Pos::from_line(52, 1)));
         check(
             "wrong-start",
-            Error::UnexpectedToken("vote-status".into(), Pos::from_line(1, 1)),
+            &Error::UnexpectedToken("vote-status", Pos::from_line(1, 1)),
         );
-        check("wrong-version", Error::BadDocumentVersion(10));
+        check("wrong-version", &Error::BadDocumentVersion(10));
     }
 
     fn gettok(s: &str) -> Result<Item<'_, NetstatusKwd>> {
