@@ -60,6 +60,7 @@ pub struct AnnotatedRouterDesc {
 
 /// Annotations about a router descriptor, as stored on disc.
 #[allow(dead_code)] // don't warn about fields not getting read.
+#[derive(Default)]
 pub struct RouterAnnotation {
     /// Description of where we got this router descriptor
     source: Option<String>,
@@ -284,16 +285,6 @@ static ROUTER_SIG_RULES: Lazy<SectionRules<RouterKwd>> = Lazy::new(|| {
     rules
 });
 
-impl Default for RouterAnnotation {
-    fn default() -> Self {
-        RouterAnnotation {
-            source: None,
-            downloaded: None,
-            purpose: None,
-        }
-    }
-}
-
 impl RouterAnnotation {
     /// Extract a single RouterAnnotation (possibly empty) from a reader.
     fn take_from_reader(reader: &mut NetDocReader<'_, RouterKwd>) -> Result<RouterAnnotation> {
@@ -381,11 +372,17 @@ impl RouterDesc {
         let s = r.str();
         let (header, body, sig) = RouterDesc::parse_sections(r)?;
 
+        // Unwrap should be safe because inline `required` call should return
+        // `Error::MissingToken` if `ROUTER` is not `Ok`
+        #[allow(clippy::unwrap_used)]
         let start_offset = header.required(ROUTER)?.offset_in(s).unwrap();
 
         // ed25519 identity and signing key.
         let (identity_cert, ed25519_signing_key) = {
             let cert_tok = header.required(IDENTITY_ED25519)?;
+            // Unwrap should be safe because above `required` call should
+            // return `Error::MissingToken` if `IDENTITY_ED25519` is not `Ok`
+            #[allow(clippy::unwrap_used)]
             if cert_tok.offset_in(s).unwrap() < start_offset {
                 return Err(Error::MisplacedToken("identity-ed25519", cert_tok.pos()));
             }
@@ -406,8 +403,8 @@ impl RouterDesc {
             let master_key_tok = body.required(MASTER_KEY_ED25519)?;
             let ed_id: Ed25519Public = master_key_tok.parse_arg(0)?;
             let ed_id: ll::pk::ed25519::Ed25519Identity = ed_id.into();
-            #[cfg(not(fuzzing))]
             if ed_id != identity_cert.peek_signing_key().into() {
+                #[cfg(not(fuzzing))]
                 return Err(Error::BadObjectVal(
                     master_key_tok.pos(),
                     "master-key-ed25519 does not match key in identity-ed25519".into(),
@@ -425,7 +422,11 @@ impl RouterDesc {
 
         let ed_sig = sig.required(ROUTER_SIG_ED25519)?;
         let rsa_sig = sig.required(ROUTER_SIGNATURE)?;
+        // Unwrap should be safe because above `required` calls should return
+        // an `Error::MissingToken` if `ROUTER_...` is not `Ok`
+        #[allow(clippy::unwrap_used)]
         let ed_sig_pos = ed_sig.offset_in(s).unwrap();
+        #[allow(clippy::unwrap_used)]
         let rsa_sig_pos = rsa_sig.offset_in(s).unwrap();
 
         if ed_sig_pos > rsa_sig_pos {
@@ -467,6 +468,9 @@ impl RouterDesc {
         let (nickname, ipv4addr, orport, dirport) = {
             let rtrline = header.required(ROUTER)?;
             (
+                // Unwrap should be safe because above `required` should return
+                // an `Error::MissingToken` if `ROUTER` is not `Ok`
+                #[allow(clippy::unwrap_used)]
                 rtrline.arg(0).unwrap().to_string(),
                 Some(rtrline.parse_arg::<net::Ipv4Addr>(1)?),
                 rtrline.parse_arg(2)?,
@@ -562,7 +566,7 @@ impl RouterDesc {
                 ipv6addr = Some((*a.ip(), a.port()));
                 break;
             }
-            // We skip over unparseable addresses. Is that right?
+            // We skip over unparsable addresses. Is that right?
         }
 
         // platform
@@ -592,6 +596,8 @@ impl RouterDesc {
                 .args_as_str()
                 .parse()
                 .map_err(|e| Error::BadPolicy(p.pos(), e))?,
+            // Unwrap is safe here because str is not empty
+            #[allow(clippy::unwrap_used)]
             None => "reject 1-65535".parse::<PortPolicy>().unwrap(),
         };
 
@@ -613,6 +619,8 @@ impl RouterDesc {
             identity_cert.expiry(),
             crosscert_cert.expiry(),
         ];
+        // Unwrap is safe here because `expirations` array is not empty
+        #[allow(clippy::unwrap_used)]
         let expiry = *expirations.iter().max().unwrap();
 
         let start_time = published - time::Duration::new(ROUTER_PRE_VALIDITY_SECONDS, 0);
@@ -686,9 +694,9 @@ fn advance_to_next_routerdesc(reader: &mut NetDocReader<'_, RouterKwd>, annotate
 
 impl<'a> RouterReader<'a> {
     /// Construct a RouterReader to take router descriptors from a string.
-    pub fn new(s: &'a str, allow: AllowAnnotations) -> Self {
+    pub fn new(s: &'a str, allow: &AllowAnnotations) -> Self {
         let reader = NetDocReader::new(s);
-        let annotated = allow == AllowAnnotations::AnnotationsAllowed;
+        let annotated = allow == &AllowAnnotations::AnnotationsAllowed;
         RouterReader { annotated, reader }
     }
 
@@ -748,6 +756,7 @@ impl<'a> Iterator for RouterReader<'a> {
 
 #[cfg(test)]
 mod test {
+    #![allow(clippy::unwrap_used)]
     use super::*;
     const TESTDATA: &str = include_str!("../../testdata/routerdesc1.txt");
 
@@ -783,38 +792,38 @@ mod test {
     fn test_bad() {
         use crate::types::policy::PolicyError;
         use crate::Pos;
-        fn check(fname: &str, e: Error) {
+        fn check(fname: &str, e: &Error) {
             let text = read_bad(fname);
             let rd = RouterDesc::parse(&text);
             assert!(rd.is_err());
-            assert_eq!(rd.err().unwrap(), e);
+            assert_eq!(&rd.err().unwrap(), e);
         }
 
         check(
             "bad-sig-order",
-            Error::UnexpectedToken("router-sig-ed25519", Pos::from_line(50, 1)),
+            &Error::UnexpectedToken("router-sig-ed25519", Pos::from_line(50, 1)),
         );
         check(
             "bad-start1",
-            Error::MisplacedToken("identity-ed25519", Pos::from_line(1, 1)),
+            &Error::MisplacedToken("identity-ed25519", Pos::from_line(1, 1)),
         );
-        check("bad-start2", Error::MissingToken("identity-ed25519"));
+        check("bad-start2", &Error::MissingToken("identity-ed25519"));
         check(
             "mismatched-fp",
-            Error::BadArgument(
+            &Error::BadArgument(
                 Pos::from_line(12, 1),
                 "fingerprint does not match RSA identity".into(),
             ),
         );
-        check("no-ed-sk", Error::MissingToken("identity-ed25519"));
+        check("no-ed-sk", &Error::MissingToken("identity-ed25519"));
 
         check(
             "bad-cc-sign",
-            Error::BadArgument(Pos::from_line(34, 26), "not 0 or 1".into()),
+            &Error::BadArgument(Pos::from_line(34, 26), "not 0 or 1".into()),
         );
         check(
             "bad-ipv6policy",
-            Error::BadPolicy(Pos::from_line(43, 1), PolicyError::InvalidPolicy),
+            &Error::BadPolicy(Pos::from_line(43, 1), PolicyError::InvalidPolicy),
         );
     }
 
@@ -833,7 +842,7 @@ mod test {
 ";
         s += &read_bad("mismatched-fp");
 
-        let rd = RouterReader::new(&s, AllowAnnotations::AnnotationsAllowed);
+        let rd = RouterReader::new(&s, &AllowAnnotations::AnnotationsAllowed);
         let v: Vec<_> = rd.collect();
         assert!(v[0].is_err());
         assert!(v[1].is_ok());
