@@ -119,10 +119,10 @@ mod curve25519impl {
         type Err = Error;
         fn from_str(s: &str) -> Result<Self> {
             let b64: B64 = s.parse()?;
-            let arry: [u8; 32] = b64.as_bytes().try_into().map_err(|_| {
+            let array: [u8; 32] = b64.as_bytes().try_into().map_err(|_| {
                 Error::BadArgument(Pos::at(s), "bad length for curve25519 key.".into())
             })?;
-            Ok(Curve25519Public(arry.into()))
+            Ok(Curve25519Public(array.into()))
         }
     }
 
@@ -175,6 +175,7 @@ mod ed25519impl {
 mod timeimpl {
     use crate::{Error, Pos, Result};
     use std::time::SystemTime;
+    use time::{format_description::FormatItem, macros::format_description, PrimitiveDateTime};
 
     /// A wall-clock time, encoded in Iso8601 format with an intervening
     /// space between the date and time.
@@ -182,14 +183,16 @@ mod timeimpl {
     /// (Example: "2020-10-09 17:38:12")
     pub(crate) struct Iso8601TimeSp(SystemTime);
 
+    /// Formatting object for parsing the space-separated Iso8601 format.
+    const ISO_8601SP_FMT: &[FormatItem] =
+        format_description!("[year]-[month]-[day] [hour]:[minute]:[second]");
+
     impl std::str::FromStr for Iso8601TimeSp {
         type Err = Error;
         fn from_str(s: &str) -> Result<Iso8601TimeSp> {
-            use chrono::{DateTime, NaiveDateTime, Utc};
-            let d = NaiveDateTime::parse_from_str(s, "%Y-%m-%d %H:%M:%S")
+            let d = PrimitiveDateTime::parse(s, &ISO_8601SP_FMT)
                 .map_err(|e| Error::BadArgument(Pos::at(s), format!("invalid time: {}", e)))?;
-            let dt = DateTime::<Utc>::from_utc(d, Utc);
-            Ok(Iso8601TimeSp(dt.into()))
+            Ok(Iso8601TimeSp(d.assume_utc().into()))
         }
     }
 
@@ -261,9 +264,8 @@ mod edcert {
 
     impl super::FromBytes for UnvalidatedEdCert {
         fn from_bytes(b: &[u8], p: Pos) -> Result<Self> {
-            let cert = Ed25519Cert::decode(b).map_err(|e| {
-                Error::BadObjectVal(p, format!("Bad certificate: {}", e.to_string()))
-            })?;
+            let cert = Ed25519Cert::decode(b)
+                .map_err(|e| Error::BadObjectVal(p, format!("Bad certificate: {}", e)))?;
             Ok(Self(cert, p))
         }
         fn from_vec(v: Vec<u8>, p: Pos) -> Result<Self> {
@@ -373,6 +375,7 @@ mod fingerprint {
 
 #[cfg(test)]
 mod test {
+    #![allow(clippy::unwrap_used)]
     use super::*;
     use crate::Result;
 
